@@ -54,6 +54,22 @@ def _echo(_: Path, code: str) -> None:
     help="Suffixes of Python/mypy modules to process",
     show_default=True,
 )
+@click.option(
+    "--exclude-google-imports/--dont-exclude-google-imports",
+    default=True,
+    help="Exclude rewriting imports prefixed with google/protobuf",
+)
+@click.option(
+    "-e",
+    "--exclude-imports-glob",
+    type=str,
+    multiple=True,
+    default=[],
+    help=(
+        "Exclude imports matching a glob pattern from being rewritten. "
+        "Multiple values are allowed"
+    ),
+)
 @click.pass_context
 def main(
     ctx: click.Context,
@@ -61,14 +77,21 @@ def main(
     in_place: bool,
     create_package: bool,
     module_suffixes: list[str],
+    exclude_google_imports: bool,
+    exclude_imports_glob: list[str],
 ) -> None:
     ctx.ensure_object(dict)
+
+    if exclude_google_imports:
+        exclude_imports_glob += ("google/protobuf/*",)
+
     ctx.obj.update(
         dict(
             python_out=python_out,
             create_package=create_package,
             overwrite_callback=_overwrite if in_place else _echo,
             module_suffixes=module_suffixes,
+            exclude_imports_glob=exclude_imports_glob,
         )
     )
 
