@@ -497,6 +497,52 @@ def buf_gen_yaml_long_names(tmp_path: Path, out_long_names: Path) -> Path:
     return p
 
 
+@pytest.fixture(scope="session")
+def ignored_import_text() -> str:
+    return """
+syntax = "proto3";
+
+import "google/protobuf/empty.proto";
+import "ignored.proto";
+
+message Foo {}
+"""
+
+
+@pytest.fixture
+def out_ignored_import(tmp_path: Path) -> Path:
+    out = tmp_path / "out_ignored_import"
+    out.mkdir()
+    return out
+
+
+@pytest.fixture
+def ignored_import_proto(tmp_path: Path, ignored_import_text: str) -> Path:
+    p = tmp_path / "ignored_import.proto"
+    p.write_text(ignored_import_text)
+    tmp_path.joinpath("ignored.proto").touch()
+    return p
+
+
+@pytest.fixture
+def buf_gen_yaml_ignored_import(tmp_path: Path, out_ignored_import: Path) -> Path:
+    p = tmp_path / "buf.gen.yaml"
+    p.write_text(
+        json.dumps(
+            {
+                "version": "v1",
+                "plugins": [
+                    {
+                        "name": "python",
+                        "out": str(out_ignored_import),
+                    },
+                ],
+            },
+        )
+    )
+    return p
+
+
 def check_import_lines(result: Result, expected_lines: Iterable[str]) -> None:
     lines = result.stdout.splitlines()
     assert set(expected_lines) <= set(lines)
